---
title: Development
---

# Dependencies

-   `Django`

-   `djangorestframework`

-   `django-filter`

-   `django-autocomplete-light`

-   `django-crum`

-   `django-crispy-forms`

-   `django-tables2`

-   `rdflib`

-   `drf-spectacular`

-   `requests`

-   `django-model-utils`

-   `crispy-bootstrap5`

    The default theme used for crispy forms.

-   `django-simple-history`

    Used by `apis_core.history` to implement version tracking.

-   `pydot`

    Used in `apis_core.documentation` to create a dot representation of
    the data model.
